@@ -63,16 +63,31 @@ public:
     virtual void PushKnot(
         const Ts_KnotData *knotData,
         const VtDictionary &customData) = 0;
+    // // Overload of PushKnot that offsets the time by timeOffset and values by
+    // // valueOffset. This allows us to unroll knots in loops without having to
+    // // dispatch based on TfType comparisons.
+    // virtual void PushKnot(
+    //     const Ts_KnotData *knotData,
+    //     const VtDictionary &customData,
+    //     const double timeOffset,
+    //     const double valueOffset) = 0;
     virtual size_t SetKnot(
         const Ts_KnotData *knotData,
         const VtDictionary &customData) = 0;
 
+    // For ease of use by breakdown, double knot data to be set into any type of
+    // spline.
+    virtual size_t SetKnotFromDouble(
+        const Ts_TypedKnotData<double>* knotData,
+        const VtDictionary &customData) = 0;
+
     virtual Ts_KnotData* CloneKnotAtIndex(size_t index) const = 0;
     virtual Ts_KnotData* CloneKnotAtTime(TsTime time) const = 0;
     virtual Ts_KnotData* GetKnotPtrAtIndex(size_t index) = 0;
     virtual const Ts_KnotData* GetKnotPtrAtIndex(size_t index) const = 0;
     virtual Ts_TypedKnotData<double>
         GetKnotDataAsDouble(size_t index) const = 0;
+    virtual double GetKnotValueAsDouble(size_t index) const = 0;
 
     virtual void ClearKnots() = 0;
     virtual void RemoveKnotAtTime(TsTime time) = 0;
@@ -149,16 +164,28 @@ public:
     void PushKnot(
         const Ts_KnotData *knotData,
         const VtDictionary &customData) override;
+    // void PushKnot(
+    //     const Ts_KnotData *knotData,
+    //     const VtDictionary &customData,
+    //     const double timeOffset,
+    //     const double valueOffset) override;
     size_t SetKnot(
         const Ts_KnotData *knotData,
         const VtDictionary &customData) override;
 
+    // For ease of use while splitting, double knot data to be set
+    // into any type of spline.
+    size_t SetKnotFromDouble(
+        const Ts_TypedKnotData<double>* knotData,
+        const VtDictionary &customData) override;
+
     Ts_KnotData* CloneKnotAtIndex(size_t index) const override;
     Ts_KnotData* CloneKnotAtTime(TsTime time) const override;
     Ts_KnotData* GetKnotPtrAtIndex(size_t index) override;
     const Ts_KnotData* GetKnotPtrAtIndex(size_t index) const override;
     Ts_TypedKnotData<double>
         GetKnotDataAsDouble(size_t index) const override;
+    double GetKnotValueAsDouble(size_t index) const override;
 
     void ClearKnots() override;
     void RemoveKnotAtTime(TsTime time) override;
@@ -284,6 +311,45 @@ void Ts_TypedSplineData<T>::PushKnot(
     }
 }
 
+// template <typename T>
+// void Ts_TypedSplineData<T>::PushKnot(
+//     const Ts_KnotData *knotData,
+//     const VtDictionary &customDataIn,
+//     const double timeOffset,
+//     const double valueOffset)
+// {
+//     Ts_TypedKnotData<T> typedKnotData(
+//         *static_cast<const Ts_TypedKnotData<T>*>(knotData));
+
+//     typedKnotData.time += timeOffset;
+//     typedKnotData.value += valueOffset;
+//     typedKnotData.preValue += valueOffset;
+
+//     // Clamp to prevent infinities in types smaller than double (especially
+//     // GfHalf).
+//     if constexpr(!std::is_same_v<T, double>) {
+//         if (typedKnotData.value > std::numeric_limits<T>::max()) {
+//             typedKnotData.value = std::numeric_limits<T>::max();
+//         } else if (typedKnotData.value < std::numeric_limits<T>::lowest()) {
+//             typedKnotData.value = std::numeric_limits<T>::lowest();
+//         }
+
+//         if (typedKnotData.preValue > std::numeric_limits<T>::max()) {
+//             typedKnotData.preValue = std::numeric_limits<T>::max();
+//         } else if (typedKnotData.preValue < std::numeric_limits<T>::lowest()) {
+//             typedKnotData.preValue = std::numeric_limits<T>::lowest();
+//         }
+//     }
+
+//     times.push_back(typedKnotData.time);
+//     knots.push_back(typedKnotData);
+
+//     if (!customDataIn.empty())
+//     {
+//         customData[knotData->time] = customDataIn;
+//     }
+// }
+
 template <typename T>
 size_t Ts_TypedSplineData<T>::SetKnot(
     const Ts_KnotData* const knotData,
@@ -321,6 +387,74 @@ size_t Ts_TypedSplineData<T>::SetKnot(
     return idx;
 }
 
+template <typename T>
+size_t Ts_TypedSplineData<T>::SetKnotFromDouble(
+        const Ts_TypedKnotData<double>* knotData,
+        const VtDictionary &customDataIn)
+{
+    // If we have double data, just set it directly.
+    if constexpr(std::is_same_v<T, double>) {
+        return SetKnot(knotData, customDataIn);
+    }
+
+    Ts_TypedKnotData<T> typedData;
+
+    // Use operator= to copy base-class members.  This is admittedly weird, but
+    // it will continue working if members are added to the base class.
+    static_cast<Ts_KnotData&>(typedData) = 
+        static_cast<const Ts_KnotData&>(*knotData);
+
+    // We need to copy and convert the data from double to T. We don't want
+    // infinite values, so clamp to the largest possible finite value.
+    auto _Clamp_cast =
+        [](double v) -> T
+        {
+            if (v >= 0) {
+                return std::min(T(v), std::numeric_limits<T>::max());
+            } else {
+                return std::max(T(v), std::numeric_limits<T>::lowest());
+            }
+        };
+
+    // Convert and clamp the value fields.
+    typedData.value = _Clamp_cast(knotData->value);
+    typedData.preValue = _Clamp_cast(knotData->preValue);
+
+    // Slopes are tricky. If they overflow, we need to compute a new slope and a
+    // new width such that the new tangent end-point is as close as possible to
+    // the original tangent end point.
+
+    auto _ConvertTangent =
+        [&_Clamp_cast](double slope, double* width) -> T
+        {
+            T typedSlope = T(slope);
+            // std::isfinite<GfHalf>() is missing so use the helper from
+            // typeHelpers.h instead.
+            if (Ts_IsFinite(typedSlope)) {
+                return typedSlope;
+            }
+
+            // Convert both the slope and width to values that preserve the
+            // endpoint of the tangent as much as possible.
+            double height = *width * slope;
+
+            // typedSlope is infinite, clamp it to a finite value.
+            typedSlope = _Clamp_cast(slope);
+
+            // modify width to preserve the tangent's height.
+            *width = height / typedSlope;
+
+            return typedSlope;
+        };
+
+    typedData.preTanSlope = _ConvertTangent(knotData->preTanSlope,
+                                            &typedData.preTanWidth);
+    typedData.postTanSlope = _ConvertTangent(knotData->postTanSlope,
+                                             &typedData.postTanWidth);
+
+    return SetKnot(&typedData, customDataIn);
+}
+
 template <typename T>
 Ts_KnotData*
 Ts_TypedSplineData<T>::CloneKnotAtIndex(
@@ -382,6 +516,16 @@ Ts_TypedSplineData<T>::GetKnotDataAsDouble(
     return out;
 }
 
+// Depending on T, this is either a verbatim copy or an increase in precision.
+template <typename T>
+double
+Ts_TypedSplineData<T>::GetKnotValueAsDouble(
+    const size_t index) const
+{
+    const Ts_TypedKnotData<T> &typedData = knots[index];
+    return typedData.value;
+}
+
 template <typename T>
 void Ts_TypedSplineData<T>::ClearKnots()
 {
