@@ -13,10 +13,6 @@
 #include "pxr/pxr.h"
 #include "pxr/external/boost/python/common.hpp"
 
-#ifndef PXR_USE_INTERNAL_BOOST_PYTHON
-#include <boost/python/register_ptr_to_python.hpp>
-#else
-
 #include "pxr/external/boost/python/pointee.hpp"
 #include "pxr/external/boost/python/object.hpp"
 #include "pxr/external/boost/python/object/class_wrapper.hpp"
@@ -38,7 +34,6 @@ void register_ptr_to_python()
 
 }} // namespace PXR_BOOST_NAMESPACE::python
 
-#endif // PXR_USE_INTERNAL_BOOST_PYTHON
 #endif // PXR_EXTERNAL_BOOST_PYTHON_REGISTER_PTR_TO_PYTHON_HPP
 
 
