@@ -57,6 +57,11 @@ PXR_NAMESPACE_OPEN_SCOPE
     (shutterOpen)                                                 \
     (shutterClose)                                                \
     (exposure)                                                    \
+    (exposureTime)                                                \
+    (exposureIso)                                                 \
+    (exposureFStop)                                               \
+    (exposureResponsivity)                                        \
+    (linearExposureScale)                                         \
                                                                   \
     /* how to match window with different aspect */               \
     (windowPolicy)                                                \
@@ -236,10 +241,26 @@ public:
         return _shutterClose;
     }
 
+    /// Get the raw exposure exponent value.
+    ///
+    /// This the same as the value stored in the exposure attribute on the
+    /// underlying camera.  Note that in most cases, you will want to use
+    /// GetLinearExposureScale() instead of this method, as it is the computed
+    /// end result of all related exposure attributes.
+    /// GetExposure() is retained as-is for backward compatibility.
     float GetExposure() const {
         return _exposure;
     }
 
+    /// Get the computed linear exposure scale from the underlying camera.
+    ///
+    /// Scaling the image brightness by this value will cause the various
+    /// exposure controls on \ref UsdGeomCamera to behave like those of a real
+    /// camera to control the exposure of the image.
+    float GetLinearExposureScale() const {
+        return _linearExposureScale;
+    }
+
     TfToken GetLensDistortionType() const {
         return _lensDistortionType;
     }
@@ -313,10 +334,17 @@ protected:
     float                   _splitDiopterWidth2;
     float                   _splitDiopterFocusDistance2;
 
-    // shutter/lighting
+    // shutter
     double                  _shutterOpen;
     double                  _shutterClose;
+
+    // exposure
     float                   _exposure;
+    float                   _exposureTime;
+    float                   _exposureIso;
+    float                   _exposureFStop;
+    float                   _exposureResponsivity;
+    float                   _linearExposureScale;
 
     // lens distortion
     TfToken                 _lensDistortionType;
