@@ -652,10 +652,13 @@ private:
     // based applications that rely on the HdChangeTracker for invalidating
     // state on Hydra prims.
     friend class HdRenderIndex;
+    friend class HdDirtyList;
     // Does not take ownership. The HdRenderIndex manages the lifetime of this
     // scene index.
     HdRetainedSceneIndex * _emulationSceneIndex;
+    bool _disableEmulationAPI;
     void _SetTargetSceneIndex(HdRetainedSceneIndex *emulationSceneIndex);
+    void _SetDisableEmulationAPI(bool);
 
     // Private methods which implement the behaviors of their public
     // equivalents. The public versions check to see if legacy emulation is
