@@ -117,16 +117,18 @@ public:
     HdBorderColor borderColor;
     bool enableCompare;
     HdCompareFunction compareFunction;
+    uint32_t maxAnisotropy;
 
     HD_API
     HdSamplerParameters();   
 
     HD_API
     HdSamplerParameters(HdWrap wrapS, HdWrap wrapT, HdWrap wrapR, 
-        HdMinFilter minFilter, HdMagFilter magFilter, 
+        HdMinFilter minFilter, HdMagFilter magFilter,
         HdBorderColor borderColor=HdBorderColorTransparentBlack,
         bool enableCompare=false, 
-        HdCompareFunction compareFunction=HdCmpFuncNever);
+        HdCompareFunction compareFunction=HdCmpFuncNever,
+        uint32_t maxAnisotropy=16);
 
     HD_API 
     bool operator==(const HdSamplerParameters &other) const;
