@@ -10,10 +10,33 @@
 #include "pxr/pxr.h"
 #include "pxr/imaging/hdsi/api.h"
 #include "pxr/usd/sdf/path.h"
+#include "pxr/base/tf/declarePtrs.h"
+#include "pxr/base/tf/token.h"
+#include <optional>
 
 PXR_NAMESPACE_OPEN_SCOPE
 
+TF_DECLARE_WEAK_AND_REF_PTRS(HdSceneIndexBase);
+
 class HdCollectionExpressionEvaluator;
+class HdCollectionsSchema;
+class SdfPathExpression;
+
+/// --------------------------------------------------------------------------
+/// General use collection utilities.
+/// --------------------------------------------------------------------------
+
+/// Extracts and compiles the membership expression of the collection
+/// with the given \p collectionName, if it exists.
+///
+HDSI_API
+void
+HdsiUtilsCompileCollection(
+    HdCollectionsSchema &collections,
+    TfToken const& collectionName,
+    HdSceneIndexBaseRefPtr const& sceneIndex,
+    SdfPathExpression *expr,
+    std::optional<HdCollectionExpressionEvaluator> *eval);
 
 /// --------------------------------------------------------------------------
 /// Utilities to evaluate membership expressions for collections with pruning
