@@ -8,6 +8,9 @@
 #define PXR_IMAGING_HGI_SAMPLER_H
 
 #include "pxr/pxr.h"
+
+#include "pxr/base/tf/envSetting.h"
+
 #include "pxr/imaging/hgi/api.h"
 #include "pxr/imaging/hgi/enums.h"
 #include "pxr/imaging/hgi/handle.h"
@@ -18,6 +21,12 @@
 
 PXR_NAMESPACE_OPEN_SCOPE
 
+/// Sets the maximum anisotropic filtering ratio for all samplers.
+/// By default this is 16x. The actual value used depends on the
+/// device limits. A value of 1 effectively disables anisotropic sampling.
+///
+HGI_API
+extern TfEnvSetting<int> HGI_MAX_ANISOTROPY;
 
 /// \struct HgiSamplerDesc
 ///
@@ -42,6 +51,11 @@ PXR_NAMESPACE_OPEN_SCOPE
 ///    Enables sampler comparison against a reference value during lookups.</li>
 /// <li>compareFunction: 
 ///    The comparison function to apply if sampler compare is enabled.</li>
+/// <li>maxAnisotropy:
+///    Maximum anisotropic filtering ratio. The default value of 16 corresponds
+///    to the previously internal default value. The actual value used is subject
+///    to the device maximum supported anisotropy and the HGI_MAX_ANISOTROPY
+///    setting. A value of 1 effectively disables anisotropic sampling.</li>
 /// </ul>
 ///
 struct HgiSamplerDesc
@@ -56,6 +70,7 @@ struct HgiSamplerDesc
         , borderColor(HgiBorderColorTransparentBlack)
         , enableCompare(false)
         , compareFunction(HgiCompareFunctionNever)
+        , maxAnisotropy(16)
     {}
 
     std::string debugName;
@@ -68,6 +83,7 @@ struct HgiSamplerDesc
     HgiBorderColor borderColor;
     bool enableCompare;
     HgiCompareFunction compareFunction;
+    uint32_t maxAnisotropy;
 };
 
 HGI_API
