@@ -1,25 +1,8 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_SDF_LIST_PROXY_H
 #define PXR_USD_SDF_LIST_PROXY_H
@@ -58,6 +41,10 @@ public:
     typedef typename TypePolicy::value_type value_type;
     typedef std::vector<value_type> value_vector_type;
 
+    /// Returned from \ref Find when a value could not be located in the
+    /// list of operations. 
+    static const size_t invalidIndex = -1;
+
 private:
     // Proxies an item in a list editor list.
     class _ItemProxy {
@@ -600,9 +587,11 @@ public:
         return (_Validate() ? _listEditor->Count(_op, value) : 0);
     }
 
+    /// Returns the index of \p value in the list of operations.  If \p value
+    /// is not found, then \ref invalidIndex is returned instead.
     size_t Find(const value_type& value) const
     {
-        return (_Validate() ? _listEditor->Find(_op, value) : size_t(-1));
+        return (_Validate() ? _listEditor->Find(_op, value) : invalidIndex);
     }
 
     void Insert(int index, const value_type& value)
@@ -616,7 +605,7 @@ public:
     void Remove(const value_type& value)
     {
         size_t index = Find(value);
-        if (index != size_t(-1)) {
+        if (index != invalidIndex) {
             Erase(index);
         }
         else {
