@@ -1,25 +1,8 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_USD_PRIM_DATA_H
 #define PXR_USD_USD_PRIM_DATA_H
@@ -40,8 +23,6 @@
 
 #include "pxr/usd/sdf/path.h"
 
-#include <boost/intrusive_ptr.hpp>
-
 #include <atomic>
 #include <cstdint>
 #include <vector>
@@ -326,10 +307,10 @@ private:
     Usd_PrimFlagBits _flags;
 
     // intrusive_ptr core primitives implementation.
-    friend void intrusive_ptr_add_ref(const Usd_PrimData *prim) {
+    friend void TfDelegatedCountIncrement(const Usd_PrimData *prim) noexcept {
         prim->_refCount.fetch_add(1, std::memory_order_relaxed);
     }
-    friend void intrusive_ptr_release(const Usd_PrimData *prim) {
+    friend void TfDelegatedCountDecrement(const Usd_PrimData *prim) noexcept {
         if (prim->_refCount.fetch_sub(1, std::memory_order_release) == 1)
             delete prim;
     }
