@@ -11,22 +11,22 @@
 #include "pxr/usd/usdHydra/api.h"
 #include "pxr/base/tf/token.h"
 
-#include "pxr/usd/ndr/declare.h"
-#include "pxr/usd/ndr/discoveryPlugin.h"
-#include "pxr/usd/ndr/parserPlugin.h"
+#include "pxr/usd/sdr/declare.h"
+#include "pxr/usd/sdr/discoveryPlugin.h"
+#include "pxr/usd/sdr/parserPlugin.h"
 
 PXR_NAMESPACE_OPEN_SCOPE
 
-class UsdHydraDiscoveryPlugin : public NdrDiscoveryPlugin {
+class UsdHydraDiscoveryPlugin : public SdrDiscoveryPlugin {
 public:
     UsdHydraDiscoveryPlugin() = default;
 
     ~UsdHydraDiscoveryPlugin() override = default;
     
-    virtual NdrNodeDiscoveryResultVec DiscoverNodes(const Context &context) 
+    virtual SdrShaderNodeDiscoveryResultVec DiscoverShaderNodes(const Context &context) 
         override;
 
-    virtual const NdrStringVec& GetSearchURIs() const override;
+    virtual const SdrStringVec& GetSearchURIs() const override;
 };
 
 PXR_NAMESPACE_CLOSE_SCOPE
