@@ -110,6 +110,9 @@ INSTANCE_NAME_PLACEHOLDER = \
 # Custom metadata tokens for user doc
 USERDOC_BRIEF = "userDocBrief"
 USERDOC_FULL = "userDoc"
+# Arbitrarily picked max length for userDocBrief -- if we end up having to use
+# documentation metadata as a fallback, we truncate to this length.
+MAX_LENGTH_FOR_USERDOCBRIEF = 500
 
 #------------------------------------------------------------------------------#
 # Parsed Objects                                                               #
@@ -515,6 +518,7 @@ class ClassInfo(object):
         self.rels = {}
         self.attrOrder = []
         self.relOrder = []
+        self.propertyOrder = []
         self.apiSchemaOverridePropertyNames = []
         self.tokens = set()
 
@@ -854,20 +858,13 @@ def _GetAPISchemaOverridePropertyNames(usdPrim, propertyNamespace):
            
     return apiSchemaOverridePropertyNames          
 
-def ParseUsd(usdFilePath):
-    sdfLayer = Sdf.Layer.FindOrOpen(usdFilePath)
-    stage = Usd.Stage.Open(sdfLayer)
+def _GenerateClassInfo(stage, sdfPrims, useLiteralIdentifier):
     classes = []
-
+    classInfos = dict()
     hasInvalidFields = False
-    # Node that we do not want to auto promote the stage to use literal
-    # identifier if all any of the layers (this or sublayers) defined it. But we
-    # just care of the sdfLayer of the schema being generated, and hence only
-    # query the presence of useLiteralIdentifier on the sdfLayer metadata.
-    useLiteralIdentifier = _UseLiteralIdentifierForLayer(sdfLayer)
 
     # PARSE CLASSES
-    for sdfPrim in sdfLayer.rootPrims:
+    for sdfPrim in sdfPrims:  
         if sdfPrim.specifier != Sdf.SpecifierClass:
             continue
 
@@ -904,6 +901,14 @@ def ParseUsd(usdFilePath):
                 for s in classInfo.apiSchemasMetadata.prependedItems]
 
         classes.append(classInfo)
+        classInfos[classInfo.usdPrimTypeName] = classInfo
+
+        # Store property order 
+        for propName in sdfPrim.propertyOrder:
+            name, _ = _GetNameAndGeneratedSchemaPropNameForPropInfo(
+                propName, classInfo)
+            classInfo.propertyOrder.append(name)
+
         #
         # We don't want to use the composed property names here because we only
         # want the local properties declared directly on the class, which the
@@ -968,7 +973,42 @@ def ParseUsd(usdFilePath):
         classInfo.apiSchemaOverridePropertyNames = \
             _GetAPISchemaOverridePropertyNames(
                 usdPrim, classInfo.propertyNamespace)
+        
+        if hasInvalidFields:
+            raise Exception('Invalid fields specified in schema.')
+        
+    return classes, classInfos
     
+def ParseUsd(usdFilePath):
+    sdfLayer = Sdf.Layer.FindOrOpen(usdFilePath)
+    stage = Usd.Stage.Open(sdfLayer)
+    allSchemas = []
+
+    # Node that we do not want to auto promote the stage to use literal
+    # identifier if all any of the layers (this or sublayers) defined it. But we
+    # just care of the sdfLayer of the schema being generated, and hence only
+    # query the presence of useLiteralIdentifier on the sdfLayer metadata.
+    useLiteralIdentifier = _UseLiteralIdentifierForLayer(sdfLayer)
+    classes, classInfos = _GenerateClassInfo(stage, sdfLayer.rootPrims, useLiteralIdentifier)
+
+    # Compile list of all reflected API schemas for this module's schemas
+    reflectedSchemas = []
+    for sdfPrim in sdfLayer.rootPrims:
+        if 'reflectedAPISchemas' in sdfPrim.customData:
+            reflectedSchemas.extend(sdfPrim.customData['reflectedAPISchemas'])
+
+    # Find the sdfPrim for each reflected schema
+    for usdPrim in stage.TraverseAll():
+        if usdPrim.GetName() in reflectedSchemas:
+            allSchemas.append(usdPrim.GetPrimStack()[0])
+
+    allSchemas.extend(sdfLayer.rootPrims)
+
+    # Store information about reflected API schemas
+    # for use in later code generation
+    _, reflectedClassInfos = _GenerateClassInfo(stage, allSchemas, useLiteralIdentifier)
+    reflectedClassInfos.update(classInfos)
+
     for classInfo in classes:
         # If this is an applied API schema that does not inherit from 
         # UsdAPISchemaBase directly, ensure that the parent class is also 
@@ -1007,9 +1047,6 @@ def ParseUsd(usdFilePath):
                         " single-apply or multiple-apply." % 
                         (classInfo.cppClassName,  parentClassInfo.cppClassName))
         
-    if hasInvalidFields:
-        raise Exception('Invalid fields specified in schema.')
-
     return (_GetLibName(sdfLayer),
             _GetLibPath(sdfLayer),
             _GetLibPrefix(sdfLayer),
@@ -1017,7 +1054,7 @@ def ParseUsd(usdFilePath):
             _GetUseExportAPI(sdfLayer),
             _GetLibTokens(sdfLayer),
             _SkipCodeGenForSchemaLib(stage),
-            classes)
+            classes, reflectedClassInfos)
 
 
 #------------------------------------------------------------------------------#
@@ -1302,7 +1339,7 @@ def GatherTokens(classes, libName, libTokens,
 
 def GenerateCode(templatePath, codeGenPath, tokenData, classes, validate,
                  namespaceOpen, namespaceClose, namespaceUsing,
-                 useExportAPI, env, headerTerminatorString):
+                 useExportAPI, env, headerTerminatorString, classInfos):
     #
     # Load Templates
     #
@@ -1361,19 +1398,77 @@ def GenerateCode(templatePath, codeGenPath, tokenData, classes, validate,
         if headerTerminatorString:
             headerTerminatorString = '\n%s\n' % headerTerminatorString
 
+        # Verify that the listed reflected API schemas are valid
+        reflectedSchemas = []
+        if 'reflectedAPISchemas' in cls.customData:
+            # Get list of reflected API schemas
+            requestedReflectedSchemas = cls.customData['reflectedAPISchemas']
+            reflectedAttrNames = set()
+            reflectedRelNames = set()
+
+            # Ensure all of these schemas are also listed in appliedSchemas
+            appliedSchemas = cls.allAppliedAPISchemas
+            for schema in requestedReflectedSchemas:
+                reflectedClsInfo = classInfos[schema]
+
+                # Ensure there are no repeated attribute names among the reflected schemas.
+                duplicates = []
+                for attrName in reflectedClsInfo.attrs:
+                    if attrName in reflectedAttrNames:
+                        duplicates.append(attrName)
+                        Print.Err("ERROR: Cannot reflect attribute ", attrName, 
+                                  "from built-in applied schema ", schema, 
+                                  " as it conflicts with an attribute of the "
+                                  " same name in another reflected schema.")
+                    else:
+                        reflectedAttrNames.add(attrName)
+                
+                if len(duplicates) > 0:
+                    for duplicateAttr in duplicates:
+                        del reflectedClsInfo.attrs[duplicateAttr]
+                        reflectedClsInfo.attrOrder.remove(duplicateAttr)
+                    classInfos[schema] = reflectedClsInfo
+
+                # Ensure there are no repeated relationship names among the reflected schemas.
+                duplicates = []
+                for relName in reflectedClsInfo.rels:
+                    if relName in reflectedRelNames:
+                        duplicates.append(relName)
+                        Print.Err("ERROR: Repeated relationship name ", relName, 
+                                  "present in ", schema, ".")
+                    else:
+                        reflectedRelNames.add(relName)
+
+                if len(duplicates) > 0:
+                    for duplicateRel in duplicates:
+                        del reflectedClsInfo.rels[duplicateRel]
+                        reflectedClsInfo.relOrder.remove(duplicateRel)
+                    classInfos[schema] = reflectedClsInfo
+
+                if schema not in appliedSchemas:
+                    raise _GetSchemaDefException(
+                        "Schemas listed in reflectedAPISchemas must be applied "
+                        "schemas. This schema is not present in the apiSchemas metadata field.", schema)
+                if schema not in classInfos:
+                    Print.Err("ERROR: Unable to find definition of", schema, ".")
+                else:
+                    reflectedSchemas.append(schema)            
+
         customCode = _ExtractCustomCode(clsHFilePath,
                 default='};\n\n%s\n%s' % (
                     namespaceClose, headerTerminatorString))
+
         _WriteFile(clsHFilePath,
                    headerTemplate.render(
-                       cls=cls, hasTokenAttrs=hasTokenAttrs) + customCode,
+                       cls=cls, hasTokenAttrs=hasTokenAttrs, appliedSchemas=reflectedSchemas, classes=classInfos) + customCode,
                    validate)
+        
 
         # source file
         clsCppFilePath = os.path.join(codeGenPath, cls.GetCppFile())
         customCode = _ExtractCustomCode(clsCppFilePath)
         _WriteFile(clsCppFilePath, 
-                   sourceTemplate.render(cls=cls) + customCode,
+                   sourceTemplate.render(cls=cls, appliedSchemas=reflectedSchemas, classes=classInfos) + customCode,
                    validate)
         
         # wrap file
@@ -1388,7 +1483,7 @@ def GenerateCode(templatePath, codeGenPath, tokenData, classes, validate,
             customCode = _ExtractCustomCode(clsWrapFilePath, default='\nWRAP_CUSTOM {\n}\n')
 
         _WriteFile(clsWrapFilePath,
-                   wrapTemplate.render(cls=cls) + customCode, validate)
+                   wrapTemplate.render(cls=cls, appliedSchemas=reflectedSchemas, classes=classInfos) + customCode, validate)
 
 # Updates the plugInfo class metadata clsDict with the API schema application
 # metadata from the class
@@ -1562,7 +1657,7 @@ def _MakeFlattenedRegistryLayer(filePath):
             cls.typeName = demangle(cls.typeName)
 
     # In order to prevent derived classes from inheriting base class
-    # documentation metadata, we must manually replace docs here.
+    # documentation metadata, we manually replace docs here
     for layer in stage.GetLayerStack():
         for cls in layer.rootPrims:
             flatCls = flatLayer.GetPrimAtPath(cls.path)
@@ -1616,14 +1711,33 @@ def _GetUserDocForSchemaObj(obj, userDocSchemaObj):
     """
     Find brief user doc for a schema object, in either the specifically authored
     user doc info in userDocSchemaObj, or the schema obj itself.
-    Returns brief user doc string, or None if no reasonable brief user doc found
+    Returns brief user doc string (with leading and trailing whitespace 
+    stripped) or None if no reasonable brief user doc found.
     """
     # Start by looking at userDocSchemaObj for USERDOC_BRIEF customData
-    if userDocSchemaObj is not None and USERDOC_BRIEF in userDocSchemaObj.GetCustomData():
-        return userDocSchemaObj.GetCustomData().get(USERDOC_BRIEF)
-    else:
+    if (userDocSchemaObj is not None 
+        and USERDOC_BRIEF in userDocSchemaObj.GetCustomData()):
+        return userDocSchemaObj.GetCustomData().get(USERDOC_BRIEF).strip()
+    elif USERDOC_BRIEF in obj.customData:
         # See if USERDOC_BRIEF exists on schema object's custom data
-        return obj.customData.get(USERDOC_BRIEF)
+        return obj.customData.get(USERDOC_BRIEF).strip()
+    elif obj.GetInfo('documentation'):
+        # Try and use the first sentence of 'documentation' if no 
+        # userDocBrief authored. Use a regex to deal with sentences with
+        # "." file extensions. 
+        sentenceExp = r'\. |\.\n' # Look for ". " or ".\n" as end of sentence
+        workDoc = re.split(sentenceExp, obj.GetInfo('documentation'), 
+            maxsplit=1)[0].strip()
+        # Truncate very long sentences to MAX_LENGTH_FOR_USERDOCBRIEF chars
+        if len(workDoc) > MAX_LENGTH_FOR_USERDOCBRIEF:
+            workDoc = workDoc[:MAX_LENGTH_FOR_USERDOCBRIEF] + "..."
+        else:
+            # Append "." if needed (regex will omit it in match results)
+            if len(workDoc) > 0 and not workDoc.endswith('.'):
+                workDoc = workDoc + '.'
+        return workDoc
+    else:
+        return None
 
 def _UpdateUserDocForRegistry(filePath, flatLayer):
     """
@@ -1678,6 +1792,17 @@ def GenerateRegistry(codeGenPath, filePath, classes, validate, env):
     # Do this here, before we strip out customData.
     briefDict = _UpdateUserDocForRegistry(filePath, flatLayer)
 
+    # Remove 'documentation' metadata (after we've gathered brief user
+    # doc, in case we needed to substitute first sentence of documentation
+    # metadata). We no longer propagate API docs to the schema registry. Note 
+    # that 'documentation' is still used in the GenerateCode process.
+    for cls in flatLayer.rootPrims:
+        flatCls = flatLayer.GetPrimAtPath(cls.path)
+        flatCls.ClearInfo('documentation')
+        for clsProp in cls.properties:
+            flatClsProp = flatCls.GetPropertyAtPath(clsProp.path)
+            flatClsProp.ClearInfo('documentation')
+
     pathsToDelete = []
     primsToKeep = {cls.usdPrimTypeName : cls for cls in classes}
     if not flatStage.RemovePrim('/GLOBAL'):
@@ -1705,10 +1830,17 @@ def GenerateRegistry(codeGenPath, filePath, classes, validate, env):
             # Any other metadata is an error.
             allowedAPIMetadata = [
                 'specifier', 'customData', 'documentation']
-            # Single apply API schemas are also allowed to specify 'apiSchemas'
-            # metadata to include other API schemas.
+
+            # API schemas are also allowed to specify 'apiSchemas' metadata to
+            # include other API schemas.
             if apiSchemaType == SINGLE_APPLY or apiSchemaType == MULTIPLE_APPLY:
                 allowedAPIMetadata.append('apiSchemas')
+
+            # Allow 'propertyOrder'  and 'uiHints' for single-apply schemas only.
+            if apiSchemaType == SINGLE_APPLY:
+                allowedAPIMetadata.append('propertyOrder')
+                allowedAPIMetadata.append('uiHints')
+
             invalidMetadata = [key for key in p.GetAllAuthoredMetadata().keys()
                                if key not in allowedAPIMetadata]
             if invalidMetadata:
@@ -1760,6 +1892,15 @@ def GenerateRegistry(codeGenPath, filePath, classes, validate, env):
             p.SetCustomDataByKey(USERDOC_BRIEF, briefDict[workPathStr])
         for myproperty in p.GetAuthoredProperties():
             workPathStr = myproperty.GetPath()
+            if Usd.SchemaRegistry.IsMultipleApplyNameTemplate(
+                myproperty.GetName()):
+                # myproperty property name has been updated with instance
+                # information via _RenamePropertiesWithInstanceablePrefix
+                # earlier, however we populated briefDict with the original 
+                # property names from schema.usda/schemaUserDoc.usda. Resort
+                # to looking up myproperty's primPath + baseName in briefDict.
+                workPathStr = myproperty.GetPrimPath().AppendProperty(
+                    myproperty.GetBaseName())
             if workPathStr in briefDict:
                 myproperty.SetCustomDataByKey(USERDOC_BRIEF,
                  briefDict[workPathStr])
@@ -2005,7 +2146,7 @@ if __name__ == '__main__':
         useExportAPI, \
         libTokens, \
         skipCodeGen, \
-        classes = ParseUsd(schemaPath)
+        classes, classInfos = ParseUsd(schemaPath)
 
         if args.validate:
             Print('Validation on, any diffs found will cause failure.')
@@ -2037,12 +2178,12 @@ if __name__ == '__main__':
         # Generate code for schema libraries that aren't specified as codeless.
         if not skipCodeGen:
             # Gathered tokens are only used for code-full schemas.
-            tokenData = GatherTokens(classes, libName, libTokens,
+            tokenData = GatherTokens(classInfos.values(), libName, libTokens,
                                      includeSchemaIdentifierTokens=True)
             GenerateCode(templatePath, codeGenPath, tokenData, classes, 
                          args.validate,
                          namespaceOpen, namespaceClose, namespaceUsing,
-                         useExportAPI, j2_env, args.headerTerminatorString)
+                         useExportAPI, j2_env, args.headerTerminatorString, classInfos)
             # Generate Build Helper Files
             GenerateBuildHelpers(templatePath, codeGenPath, tokenData, classes, 
                                  libName, args.validate, j2_env)
